@@ -2,6 +2,8 @@
 #' @name bf_oneway_anova
 #'
 #' @importFrom BayesFactor anovaBF
+#' @importFrom dplyr anti_join mutate
+#' @importFrom rlang :=
 #'
 #' @param data A dataframe (or a tibble) from which variables specified are to
 #'   be taken. A matrix or tables will **not** be accepted.
@@ -47,7 +49,7 @@ bf_oneway_anova <- function(data,
                             output = "results",
                             hypothesis.text = TRUE,
                             paired = FALSE,
-                            k = 2,
+                            k = 2L,
                             ...) {
 
   # make sure both quoted and unquoted arguments are allowed
@@ -55,20 +57,21 @@ bf_oneway_anova <- function(data,
 
   # ============================ data preparation ==========================
 
-  # creating a dataframe
+  # have a proper cleanup with NA removal
   data %<>%
-    dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
-    dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    as_tibble(.)
+    long_to_wide_converter(
+      data = .,
+      x = {{ x }},
+      y = {{ y }},
+      paired = paired,
+      spread = FALSE
+    )
 
   # ========================= within-subjects design ==========================
 
   if (isTRUE(paired)) {
-    # converting to long format and then getting it back in wide so that the
-    # rowid variable can be used as the block variable
-    data %<>%
-      df_cleanup_paired(data = ., x = {{ x }}, y = {{ y }}) %>%
-      dplyr::mutate(.data = ., rowid = as.factor(rowid))
+    # remove NAs
+    data %<>% dplyr::mutate(.data = ., rowid = as.factor(rowid))
 
     # extracting results from Bayesian test (`y ~ x + id`) and creating a dataframe
     bf.df <-
@@ -89,9 +92,6 @@ bf_oneway_anova <- function(data,
   # ========================= between-subjects design =========================
 
   if (isFALSE(paired)) {
-    # remove NAs listwise for between-subjects design
-    data %<>% tidyr::drop_na(.)
-
     # extracting results from Bayesian test and creating a dataframe
     bf.df <-
       bf_extractor(
