@@ -136,8 +136,6 @@ testthat::test_that(
           "(BF"["10"],
           ") = ",
           "3.33",
-          ", sampling = ",
-          "joint multinomial",
           ", ",
           italic("a"),
           " = ",
@@ -156,8 +154,6 @@ testthat::test_that(
           "(BF"["10"],
           ") = ",
           "214.25",
-          ", sampling = ",
-          "joint multinomial",
           ", ",
           italic("a"),
           " = ",
@@ -175,8 +171,6 @@ testthat::test_that(
           "(BF"["01"],
           ") = ",
           "-213.98",
-          ", sampling = ",
-          "independent multinomial",
           ", ",
           italic("a"),
           " = ",
