@@ -26,8 +26,8 @@ testthat::test_that(
     set.seed(123)
     df_results <-
       bf_oneway_anova(
-        data = dat,
-        x = vore,
+        data = ggplot2::msleep,
+        x = "vore",
         y = brainwt,
         bf.prior = 0.99,
         output = "results"
@@ -37,9 +37,9 @@ testthat::test_that(
     set.seed(123)
     results1 <-
       bf_oneway_anova(
-        data = dat,
+        data = ggplot2::msleep,
         x = vore,
-        y = brainwt,
+        y = "brainwt",
         bf.prior = 0.88,
         output = "null"
       )
@@ -48,7 +48,7 @@ testthat::test_that(
     set.seed(123)
     results2 <-
       bf_oneway_anova(
-        data = dat,
+        data = ggplot2::msleep,
         x = vore,
         y = brainwt,
         bf.prior = 0.88,
@@ -244,5 +244,34 @@ testthat::test_that(
         )
       ))
     )
+
+    # data with NA
+    set.seed(123)
+    df_results_na <-
+      bf_oneway_anova(
+        data = bugs_long,
+        x = condition,
+        y = "desire",
+        paired = TRUE,
+        output = "caption"
+      )
+
+    testthat::expect_identical(
+      df_results_na,
+      ggplot2::expr(atop(
+        displaystyle(NULL),
+        expr = paste(
+          "In favor of null: ",
+          "log"["e"],
+          "(BF"["01"],
+          ") = ",
+          "-21.04",
+          ", ",
+          italic("r")["Cauchy"]^"JZS",
+          " = ",
+          "0.71"
+        )
+      ))
+    )
   }
 )
