@@ -130,12 +130,12 @@ testthat::test_that(
     testthat::expect_equal(df$bf10, df_results$bf10, tolerance = 0.001)
     testthat::expect_equal(df$log_e_bf01, df_results$log_e_bf01, tolerance = 0.001)
 
-    # extracting subtitle
+    # extracting subtitle (without NA)
     set.seed(123)
     subtitle <-
       bf_ttest(
         data = iris,
-        x = Petal.Length,
+        x = "Petal.Length",
         y = NULL,
         test.value = 5.5,
         bf.prior = 0.99,
@@ -161,5 +161,35 @@ testthat::test_that(
         )
       )
     )
+
+    # extracting subtitle (with NA)
+    set.seed(123)
+    subtitle2 <-
+      bf_ttest(
+        data = ggplot2::msleep,
+        x = brainwt,
+        y = NULL,
+        test.value = 0.25,
+        bf.prior = 0.9,
+        output = "subtitle"
+      )
+
+    testthat::expect_identical(
+      subtitle2,
+      ggplot2::expr(atop(
+        displaystyle(NULL),
+        expr = paste(
+          "In favor of alternative: ",
+          "log"["e"],
+          "(BF"["10"],
+          ") = ",
+          "-2.13",
+          ", ",
+          italic("r")["Cauchy"]^"JZS",
+          " = ",
+          "0.90"
+        )
+      ))
+    )
   }
 )
